import datetime

from rest_framework import serializers


class SysRequestSerializer(serializers.Serializer):
    TransID = serializers.RegexField(
        regex='^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$')
    RequestorID = serializers.CharField()
    DateTime = serializers.DateTimeField(default=datetime.datetime.now(), format="%Y-%m-%dT%H:%M:%S.%f")


class RelativeTypeSerializer(serializers.Serializer):
    ID = serializers.CharField()
    NationalD = serializers.CharField()


class GetAppHistorySerializer(serializers.Serializer):
    Sys = SysRequestSerializer()
    NationalID = serializers.CharField()
    FBNationalID = serializers.CharField()
    ProductCode = serializers.CharField()
    MobileNumber = serializers.CharField()
    Relatives = RelativeTypeSerializer(many=True, required=False, allow_null=True)
    Attribute02 = serializers.CharField(required=False, allow_null=True)

    def is_valid(self, raise_exception=False):
        validity = super(GetAppHistorySerializer, self).is_valid(raise_exception)
        if not validity:
            return validity
        self.data['Sys']['DateTime'] = datetime.datetime.strptime(self.data['Sys']['DateTime'], "%Y-%m-%dT%H:%M:%S.%f")
        return validity


class SysResponseSerializer(serializers.Serializer):
    TransID = serializers.RegexField(
        regex='^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$')
    Code = serializers.CharField()
    DateTime = serializers.DateTimeField(default=datetime.datetime.now(), format="%Y-%m-%dT%H:%M:%S.%f")
    Description = serializers.CharField(required=False, allow_null=True)


class CustomerResponseSerializer(serializers.Serializer):
    RejectedApp = serializers.IntegerField()
    ActiveApp = serializers.IntegerField()
    TotalActiveLoansApps = serializers.IntegerField()
    ActiveLoansPrev = serializers.IntegerField()
    ActiveProductLoansApps = serializers.IntegerField()
    FamActiveLoansApps = serializers.IntegerField()
    TotalTWCust = serializers.IntegerField()
    TotalCDLCust = serializers.IntegerField()
    TotalBDLCust = serializers.IntegerField()
    TotalPLCust = serializers.IntegerField()
    ActiveLGLoan = serializers.IntegerField()
    TotalPLRobo = serializers.IntegerField()
    ActiveLoansPrev2Months = serializers.IntegerField()
    FamOutstandingAmount = serializers.IntegerField()
    FamRequestedLoanAmount = serializers.IntegerField()
    # TotalLGLoan = serializers.IntegerField()
    TotalNonCardEMI = serializers.IntegerField()
    TotalCreditLimitCRC = serializers.IntegerField()
    TotalEMIActiveLoans = serializers.IntegerField()

class RelativesResponseSerializer(serializers.Serializer):
    ID = serializers.CharField()
    NationalID = serializers.CharField()
    RelTotalActiveLoansApps = serializers.CharField()


class ReturnAppHistorySerializer(serializers.Serializer):
    Sys = SysResponseSerializer()
    Customer = CustomerResponseSerializer()
    Relatives = RelativesResponseSerializer(many=True, required=False, allow_null=True)