import uuid

from rest_framework import status
from rest_framework.permissions import AllowAny

from base_app.views import GenericSoapAPIView, BaseAPIView
from base_app import utils as base_app_utils
from base_app.utils import add_entry_to_celery_audit_tracker, get_celery_queue
from base_app.tasks import generic_task2

from fec_apphistory import constants as fec_apphistory_constants
from fec_apphistory import serializers as fec_apphistory_serializers
from fec_apphistory.conf import settings


class GetAppLoanHistory(GenericSoapAPIView):
    """
    API to get total amount for App History
    """
    permission_classes = (AllowAny,)
    request_serializer_class = fec_apphistory_serializers.GetAppHistorySerializer
    response_serializer_class= fec_apphistory_serializers.ReturnAppHistorySerializer
    request_url = settings.APPHISTORY_WSDL
    username = settings.APPHISTORY_USERNAME
    password = settings.APPHISTORY_PASSWORD
    method_name = 'GetAppLoanHistory'
    success_code_list = [1, '1', 3, '3']
    success_code_eval = "data.get('data', {}).get('Sys', {}).get('Code')"
    return_codes = fec_apphistory_constants.APPHISTORY_RETURN_CODES


class GetAppLoanHistoryAsync(BaseAPIView):
    permission_classes = (AllowAny,)

    def post(self, request):
        serializer = fec_apphistory_serializers.GetAppHistorySerializer(data=request.data)
        if serializer.is_valid():
            task_id = str(uuid.uuid4())
            queue_name = get_celery_queue("appHistory")
            celery_audit_tracker_obj = add_entry_to_celery_audit_tracker(queue_name, 'appHistory', '', request.data,
                                                                         1, task_id, serializer.validated_data)
            generic_task2.apply_async(args=[celery_audit_tracker_obj.id], queue=queue_name, task_id=task_id)
            return base_app_utils.response({"task_id": task_id, "message": "Request enqueued successfully"})
        else:
            error = serializer.errors
            error.update({'type': 's', 'reason': 'bad request'})
            return base_app_utils.response(None, status.HTTP_400_BAD_REQUEST, error=error)
